package com.jkcredit.invoice.hub.service.apiCarFree;

import com.alibaba.fastjson.JSONObject;
import com.jkcredit.invoice.hub.spi.rest.data.ApiResponseData;

/**
 * @description: 无车api接口
 * @author: xusonglin
 * @create: 2020/1/16 21:52
 * @version: V1.0
 **/
public interface ApiCarFreeService {
    // 无车备案车辆查询
    ApiResponseData vehicleRegisterQuery(JSONObject param);

    // 无车车辆备案
    ApiResponseData vehicleRegister(JSONObject param);

    // 无车运单开始指令
    ApiResponseData wayBillStart(JSONObject param);

    // 无车运单结束指令
    ApiResponseData wayBillEnd(JSONObject param);

    // 无车历史运单开始指令
    ApiResponseData wayBillHistoryStart(JSONObject param);

    // 无车历史运单结束指令
    ApiResponseData wayBillHistoryEnd(JSONObject param);

    // 无车运单编号查询发票(直连上游，不查数据库)
    ApiResponseData wayBillNumFindInvoice(JSONObject param);

    // 无车运单编号查询发票（先查数据库，数据库不存在则查询接口+计费规则）
    ApiResponseData findInvoice(JSONObject param);

    // 获取无车未查询过发票的运单编号
    ApiResponseData findNoSearchNums(JSONObject param);
}
